#!/bin/bash
# for a psycho test, use 6 disconnected computers , 
#   one for qgenHid
#   for each arm, one for qRotat
#   for each arm, one for qPolarize
#   one for qStat

##### default values for all the used parameters #########

# float version is the default
V=""

# use V i for the integer version or only i
#V="i"


# number of initial pairs
num_pat=10000000

# index of the test if you need to keep history
num_test=1

# nick names of the arms
arm1="alice"
arm2="bob"

# depth parameters

# ring size in degrees around the angle
largarc=25.75

# number of sections in this ring
section=7

# number of doors of the potential
doors=20

# base of the restriction to 4 angles
R=""

if [[ "$1" == "h" ]]; then
	echo -e "\tbash bat.sh argument value ..."
	echo -e "\t\tif an argument is not specified, the default value is used"
	echo -e "\tex : bash bat.sh largarc 20 section 5 doors 12"
	echo -e ""
	echo -e "\tAll the default values may be overridden:"
	echo -e "\t\tV \"${V}\" # float version ; use V i for the integer version or only i"
	echo -e "\t\tnum_pat ${num_pat}	 # number of initial pairs"
	echo -e "\t\tnum_test ${num_test} # index of the test if you need to keep history"
	echo -e "\t\tarm1 ${arm1} # nick names of the arms"
	echo -e "\t\tarm2 ${arm2}"
	echo -e "\t\tlargarc ${largarc}  # ring size in degrees around the angle"
	echo -e "\t\tsection ${section}  # number of sections in this ring"
	echo -e "\t\tdoors ${doors} # number of doors of the potential"
	echo -e "\t\tR \"${R}\"  # base of the restriction to 4 angles , ignore for all"
	echo -e ""
	echo -e "\t\tfor a copy/paste/edit :"
	echo -e "bash bat.sh V i num_pat ${num_pat} num_test ${num_test} arm1 ${arm1} arm2 ${arm2} largarc ${largarc} section ${section} doors ${doors}"
	echo -e ""
	exit;
fi

while true; do
	if [ $1 ]; then
		if [[ "$1" == "i" ]]; then
			V="i"
			shift
		else
			eval $1=\$2
			shift
			shift
		fi

	else
		break # no more args
	fi
done

if [[ $R == "4" ]]; then
	restr1="0"
	restr2="2"
else
	restr1=""
	restr2=""
fi

# generate the common variables files ( also called hidden variables file )
./bin/${V}qgenHid ${num_pat} data/hid.${num_test}.${num_pat}

# compute the rotations of the arm 1
./bin/${V}qRotat ${num_pat} data/${arm1}.rot.${num_test}.${num_pat} ${restr1}


# compute the polarisations of the arm 1 with the common hidden variables and the arm1 rotations files 
./bin/${V}qPolarize ${largarc} ${section} ${doors} data/hid.${num_test}.${num_pat} data/${arm1}.rot.${num_test}.${num_pat} data/${arm1}.polarized.${num_test}.${num_pat}

# compute the rotations of the arm 2
# because the randomizer is seeded on the time, you must include between the 2 rotations computations a long command or a sleep
./bin/${V}qRotat ${num_pat} data/${arm2}.rot.${num_test}.${num_pat} ${restr2}

# compute the polarisations of the arm 2 with the common hidden variables and the arm2 rotations files 
./bin/${V}qPolarize ${largarc} ${section} ${doors} data/hid.${num_test}.${num_pat} data/${arm2}.rot.${num_test}.${num_pat} data/${arm2}.polarized.${num_test}.${num_pat}

# do the stats with the output of the polarizer
./bin/${V}qStat data/${arm1}.polarized.${num_test}.${num_pat} data/${arm2}.polarized.${num_test}.${num_pat} data/${arm1}.${arm2}.${num_test}.${num_pat}

# you can either analyze the tabbed document with you software, with an excel-like software or rewrite qStat to fit your needs

# optionnal - to ignore in most cases
/bin/cp data/${arm1}.${arm2}.${num_test}.${num_pat} ../www/
ls -l data/
